@@ -5,6 +5,8 @@ class ETLAdapter(Enum):
     GEDYS = "gedys"
     HUBSPOT = "hubspot"
     ZENTIS = "zentis"
+    GENERICODBC = "genericodbc"
+    INFORCOM = "inforcom"
 
 
 class ETLStep(Enum):
@@ -15,7 +17,11 @@ class ETLStep(Enum):
 
 class ETLBaseObjectType(Enum):
     def __init__(
-        self, label: str, guid: str, sentiment_analysis_fields: list[str] | None = None
+        self,
+        label: str,
+        guid: str,
+        sentiment_analysis_fields: list[str] | None = None,
+        big_data: bool = False,
     ):
         """
         Initializes the ETLBaseObjectType with label, guid, and optional sentiment analysis fields.
@@ -23,6 +29,7 @@ class ETLBaseObjectType(Enum):
         self._label = label
         self._guid = guid
         self._sentiment_analysis_fields = sentiment_analysis_fields
+        self._big_data = big_data
 
     @property
     def label(self) -> str:
@@ -40,6 +47,10 @@ class ETLBaseObjectType(Enum):
     def sentiment_analysis_fields(self) -> list[str] | None:
         return self._sentiment_analysis_fields
 
+    @property
+    def big_data(self) -> bool:
+        return self._big_data
+    
     @property
     def filename(self) -> str:
         return (
