@@ -26,12 +26,14 @@ class ZentisLoad:
         """
         filehandler = ETLFileHandler()
 
-        data = filehandler.readJSON(
-            adapter=ETLAdapter.ZENTIS,
-            step=ETLStep.TRANSFORM,
-            entity=ZentisObjectType.JOINED_DATA,
-        )
-        self._load_data(ZentisObjectType.JOINED_DATA, data)
+        for entity in ZentisObjectType:
+            
+            data = filehandler.readJSON(
+                adapter=ETLAdapter.ZENTIS,
+                step=ETLStep.TRANSFORM,
+                entity=entity,
+            )
+            self._load_data(entity, data)
 
     def _load_data(self, entity: ZentisObjectType, data: list) -> None:
         """
@@ -42,13 +44,6 @@ class ZentisLoad:
 
         self.logger.info(f"Loading {entity.label} data into Nemo")
         df = pd.DataFrame(data)
-        filehandler = ETLFileHandler()
-        filehandler.writeDF(
-            adapter=ETLAdapter.ZENTIS,
-            step=ETLStep.LOAD,
-            entity=entity,
-            data=df,
-        )
         
         ReUploadDataFrame(
             config=self.config,
