@@ -121,21 +121,21 @@ class NemoLibrary:
     def __init__(
         self,
         config_file: str = "config.ini",
-        environment: str = None,
-        tenant: str = None,
-        userid: str = None,
-        password: str = None,
-        migman_local_project_directory: str = None,
-        migman_proALPHA_project_status_file: str = None,
-        migman_projects: list[str] = None,
-        migman_mapping_fields: list[str] = None,
-        migman_additional_fields: dict[str, list[str]] = None,
-        migman_multi_projects: dict[str, list[str]] = None,
-        metadata_directory: str = None,
-        etl_directory: str = None,
-        hubspot_api_token: str = None,
-        gedys_user_id: str = None,
-        gedys_password: str = None,
+        environment: str | None = None,
+        tenant: str | None = None,
+        userid: str | None = None,
+        password: str | None = None,
+        migman_local_project_directory: str | None = None,
+        migman_proALPHA_project_status_file: str | None = None,
+        migman_projects: list[str] | None = None,
+        migman_mapping_fields: list[str] | None = None,
+        migman_additional_fields: dict[str, list[str]] | None = None,
+        migman_multi_projects: dict[str, list[str]] | None = None,
+        metadata_directory: str | None = None,
+        etl_directory: str | None = None,
+        hubspot_api_token: str | None = None,
+        gedys_user_id: str | None = None,
+        gedys_password: str | None = None,
         foxreader_statistics_file: str | None = None,
     ):
         """
@@ -240,8 +240,8 @@ class NemoLibrary:
     def LoadReport(
         self,
         projectname: str,
-        report_guid: str = None,
-        report_name: str = None,
+        report_guid: str | None = None,
+        report_name: str | None = None,
     ) -> pd.DataFrame:
         """
         Loads a report from a specified project and returns the data as a Pandas DataFrame.
@@ -275,9 +275,9 @@ class NemoLibrary:
     def setProjectMetaData(
         self,
         projectname: str,
-        processid_column: str = None,
-        processdate_column: str = None,
-        corpcurr_value: str = None,
+        processid_column: str | None = None,
+        processdate_column: str | None = None,
+        corpcurr_value: str | None = None,
     ) -> None:
         """
         Updates metadata for a specific project, including process ID, process date, and corporate currency value.
@@ -338,7 +338,7 @@ class NemoLibrary:
         """
         MigManDatabaseAddWebInformation()
 
-    def MigManPrecheckFiles(self) -> dict[str:str]:
+    def MigManPrecheckFiles(self) -> dict[str, str]:
         """
         Performs a pre-check on files required for the Migration Manager (MigMan).
 
@@ -426,11 +426,11 @@ class NemoLibrary:
         projectname: str,
         df: pd.DataFrame,
         update_project_settings: bool = True,
-        datasource_ids: list[dict] = None,
-        global_fields_mapping: list[dict] = None,
+        datasource_ids: list[dict] | None = None,
+        global_fields_mapping: list[dict] | None = None,
         version: int = 2,
         trigger_only: bool = False,
-        import_configuration: ImportConfigurations = None,
+        import_configuration: ImportConfigurations | None = None,
         format_data: bool = True,
     ) -> None:
         ReUploadDataFrame(
@@ -451,11 +451,11 @@ class NemoLibrary:
         projectname: str,
         filename: str,
         update_project_settings: bool = True,
-        datasource_ids: list[dict] = None,
-        global_fields_mapping: list[dict] = None,
+        datasource_ids: list[dict] | None = None,
+        global_fields_mapping: list[dict] | None = None,
         version: int = 2,
         trigger_only: bool = False,
-        import_configuration: ImportConfigurations = None,
+        import_configuration: ImportConfigurations | None = None,
         format_data: bool = True,
     ) -> None:
         """
@@ -502,8 +502,8 @@ class NemoLibrary:
         projectname: str,
         displayName: str,
         querySyntax: str,
-        internalName: str = None,
-        description: str = None,
+        internalName: str | None = None,
+        description: str | None = None,
     ) -> None:
         """
         Creates or updates a report in the specified project within the NEMO system.
@@ -543,9 +543,9 @@ class NemoLibrary:
         projectname: str,
         displayName: str,
         ruleSourceInternalName: str,
-        internalName: str = None,
-        ruleGroup: str = None,
-        description: str = None,
+        internalName: str | None = None,
+        ruleGroup: str | None = None,
+        description: str | None = None,
     ) -> None:
         """
         Creates or updates a rule in the specified project within the NEMO system.
@@ -617,11 +617,11 @@ class NemoLibrary:
     def focusMoveAttributeBefore(
         self,
         projectname: str,
-        sourceDisplayName: str = None,
-        sourceInternalName: str = None,
-        targetDisplayName: str = None,
-        targetInternalName: str = None,
-        groupInternalName: str = None,
+        sourceDisplayName: str | None = None,
+        sourceInternalName: str | None = None,
+        targetDisplayName: str | None = None,
+        targetInternalName: str | None = None,
+        groupInternalName: str | None = None,
     ) -> None:
         """
         Moves an attribute in the focus tree of a specified project, positioning it before a target attribute.
