@@ -37,11 +37,11 @@ def ReUploadDataFrame(
     projectname: str,
     df: pd.DataFrame,
     update_project_settings: bool = True,
-    datasource_ids: list[dict] = None,
-    global_fields_mapping: list[dict] = None,
+    datasource_ids: list[dict] | None = None,
+    global_fields_mapping: list[dict] | None = None,
     version: int = 2,
     trigger_only: bool = False,
-    import_configuration: ImportConfigurations = None,
+    import_configuration: ImportConfigurations | None = None,
     format_data: bool = True,
 ) -> None:
 
@@ -94,11 +94,11 @@ def ReUploadFile(
     projectname: str,
     filename: str,
     update_project_settings: bool = True,
-    datasource_ids: list[dict] = None,
-    global_fields_mapping: list[dict] = None,
+    datasource_ids: list[dict] | None = None,
+    global_fields_mapping: list[dict] | None = None,
     version: int = 2,
     trigger_only: bool = False,
-    import_configuration: ImportConfigurations = None,
+    import_configuration: ImportConfigurations | None = None,
     format_data: bool = True,
 ) -> None:
     """
