@@ -13,11 +13,11 @@ __all__ = ["focusMoveAttributeBefore", "focusCoupleAttributes"]
 def focusMoveAttributeBefore(
     config: Config,
     projectname: str,
-    sourceDisplayName: str = None,
-    sourceInternalName: str = None,
-    targetDisplayName: str = None,
-    targetInternalName: str = None,
-    groupInternalName: str = None,
+    sourceDisplayName: str | None = None,
+    sourceInternalName: str | None = None,
+    targetDisplayName: str | None = None,
+    targetInternalName: str | None = None,
+    groupInternalName: str | None = None,
 ) -> None:
     """
     Moves an attribute in the focus tree of a specified project, positioning it before a target attribute.
