@@ -1,3 +1,4 @@
+import time
 import logging
 import pandas as pd
 import re
@@ -14,6 +15,8 @@ from nemo_library.utils.config import Config
 from nemo_library.features.fileingestion import ReUploadDataFrame
 from nemo_library.utils.utils import log_error
 
+from hubspot.crm.companies.exceptions import ApiException
+
 ACTIVITY_TYPES = [
     "calls",
     "communications",
@@ -73,7 +76,7 @@ ACTIVITY_TYPE_DETAILS = {
 
 DEALSTAGE_MAPPING = {
     "appointmentscheduled": "Unqualified lead​",
-    "17193482": "Qualified lead​",
+    "17193482": "Qualified lead",
     "16072556": "Presentation",
     "presentationscheduled": "Test phase",
     "decisionmakerboughtin": "Negotiation",
@@ -82,6 +85,9 @@ DEALSTAGE_MAPPING = {
     "closedlost": "closed and lost",
 }
 
+MAX_RETRIES = 5
+RETRY_DELAY = 10
+
 
 def FetchDealFromHubSpotAndUploadToNEMO(config: Config, projectname: str) -> None:
     """
@@ -323,6 +329,9 @@ def load_deal_history(hs: HubSpot, deals: pd.DataFrame) -> pd.DataFrame:
             f"deal history: {min(i + batch_size, num_deal_ids)} out of {num_deal_ids} records processed"
         )
 
+        # Throttle request rate
+        time.sleep(0.2)  # 200ms Pause per Request
+
     # Convert the list of records into a DataFrame
     history_df = pd.DataFrame(all_records)
 
@@ -364,16 +373,16 @@ def add_company_information(hs: HubSpot, deals: pd.DataFrame) -> pd.DataFrame:
     batch_size = 1000  # HubSpot API Limit
 
     for i in range(0, len(deal_ids), batch_size):
-        batch_ids = deal_ids[i:i + batch_size]
+        batch_ids = deal_ids[i : i + batch_size]
         batch_input = BatchInputPublicObjectId(inputs=batch_ids)
-        
+
         try:
             associations = hs.crm.associations.batch_api.read(
                 from_object_type="deals",
                 to_object_type="company",
                 batch_input_public_object_id=batch_input,
             )
-            
+
             for result in associations.results:
                 deal_id = result._from.id
                 to_dict = result.to
@@ -385,11 +394,16 @@ def add_company_information(hs: HubSpot, deals: pd.DataFrame) -> pd.DataFrame:
                         }
                     )
             logging.info(f"Company batch {i // batch_size + 1} loaded...")
-        except Exception as e:
-            logging.error(f"Error during loading Companies Batch {i // batch_size + 1}: {e}")
-    
-    company_association_df = pd.DataFrame(company_association_rows)
 
+            # Pause to avoid exceeding rate limits
+            time.sleep(0.2)
+
+        except Exception as e:
+            logging.error(
+                f"Error during loading Companies Batch {i // batch_size + 1}: {e}"
+            )
+
+    company_association_df = pd.DataFrame(company_association_rows)
 
     # Create a DataFrame from the expanded rows
     company_association_df = pd.DataFrame(company_association_rows)
@@ -424,7 +438,21 @@ def add_company_information(hs: HubSpot, deals: pd.DataFrame) -> pd.DataFrame:
             "limit": batch_size,
         }
 
-        company_infos = hs.crm.companies.search_api.do_search(search_request)
+        # Retry-Logik
+        for attempt in range(MAX_RETRIES):
+            try:
+                company_infos = hs.crm.companies.search_api.do_search(search_request)
+                break  # erfolgreich – Schleife abbrechen
+            except ApiException as e:
+                if e.status == 429:
+                    logging.warning(f"Rate limit hit (429). Retry in {RETRY_DELAY} seconds...")
+                    time.sleep(RETRY_DELAY)
+                else:
+                    logging.error(f"Unexpected API error: {e}")
+                    raise 
+        else:
+            log_error(f"Failed to fetch company infos after {MAX_RETRIES} attempts.")
+
 
         for company_info in company_infos.results:
             company_details.append(
@@ -447,6 +475,9 @@ def add_company_information(hs: HubSpot, deals: pd.DataFrame) -> pd.DataFrame:
             f"company association: {min(i + batch_size, total_companies)} out of {total_companies} records processed"
         )
 
+        # Pause to avoid exceeding rate limits
+        time.sleep(0.2)
+
     # Step 3: Create a DataFrame from the company details
     company_df = pd.DataFrame(company_details)
 
@@ -481,11 +512,11 @@ def load_activities(hs: HubSpot, deals: pd.DataFrame) -> pd.DataFrame:
     """
     activity_association_rows = []
     deal_ids = deals["deal_id"].unique().tolist()
-    batch_size = 1000  
+    batch_size = 1000
 
     for activity_type in ACTIVITY_TYPES:
         for i in range(0, len(deal_ids), batch_size):
-            batch_ids = deal_ids[i:i + batch_size]  
+            batch_ids = deal_ids[i : i + batch_size]
             batch_input = BatchInputPublicObjectId(inputs=batch_ids)
 
             try:
@@ -494,7 +525,7 @@ def load_activities(hs: HubSpot, deals: pd.DataFrame) -> pd.DataFrame:
                     to_object_type=activity_type,
                     batch_input_public_object_id=batch_input,
                 )
-                
+
                 for result in associations.results:
                     deal_id = result._from.id
                     to_dict = result.to
@@ -506,11 +537,17 @@ def load_activities(hs: HubSpot, deals: pd.DataFrame) -> pd.DataFrame:
                                 "update_type": activity_type,
                             }
                         )
-                
+
                 logging.info(f"{activity_type} batch {i // batch_size + 1} loaded...")
+
+                # Pause to avoid exceeding rate limits
+                time.sleep(0.2)
+
             except Exception as e:
-                logging.error(f"Fehler beim Laden von {activity_type} Batch {i // batch_size + 1}: {e}")
-    
+                logging.error(
+                    f"Fehler beim Laden von {activity_type} Batch {i // batch_size + 1}: {e}"
+                )
+
     activity_association_df = pd.DataFrame(activity_association_rows)
     return activity_association_df
 
@@ -594,6 +631,8 @@ def fetch_activity_details_batch_via_rest(
             logging.info(
                 f"Processed {processed_count} of {total_items} items for {activity_type}."
             )
+            # Pause to avoid exceeding rate limits
+            time.sleep(0.2)
         else:
             log_error(
                 f"Error fetching batch for {activity_type}: {response.status_code}, {response.text}"
@@ -696,22 +735,18 @@ def beautify_deals_drop_columns(deals: pd.DataFrame) -> pd.DataFrame:
     Notes:
     ------
     The following columns are removed if they exist:
-        - "deal_associations"
         - "deal_archived"
         - "deal_archived_at"
         - "deal_properties_with_history"
         - "deal_created_at"
         - "deal_updated_at"
-        - "deal_pipeline"
     """
     columns_to_drop = [
-        "deal_associations",
         "deal_archived",
         "deal_archived_at",
         "deal_properties_with_history",
         "deal_created_at",
         "deal_updated_at",
-        "deal_pipeline",
     ]
     deals = deals.drop(columns=columns_to_drop, errors="ignore")
     return deals
