@@ -30,6 +30,8 @@ def MigManCreateProjectTemplates(config: Config) -> None:
     local_project_directory = config.get_migman_local_project_directory()
     multi_projects = config.get_migman_multi_projects()
     projects = get_migman_project_list(config)
+    if not projects:
+        raise ValueError("No migman projects defined.")
 
     # initialize project folder structure
     initializeFolderStructure(local_project_directory)
