@@ -18,6 +18,8 @@ def MigManDeleteProjects(config: Config) -> None:
     """
     nemo_projects = getProjects(config)
     migmanprojects = get_migman_project_list(config)
+    if not migmanprojects:
+        raise ValueError("No migman projects defined.")
     migmanmappingfields = config.get_migman_mapping_fields()
     project_map = {project.displayName: project.id for project in nemo_projects}
     delete = []
