@@ -32,6 +32,8 @@ def MigManExportData(config: Config) -> None:
     local_project_directory = config.get_migman_local_project_directory()
     multi_projects = config.get_migman_multi_projects()
     projects = get_migman_project_list(config)
+    if not projects:
+        raise ValueError("No migman projects defined.")
 
     project_list_nemo = [project.displayName for project in getProjects(config)]
 
