@@ -73,6 +73,8 @@ def MigManLoadData(
     local_project_directory = config.get_migman_local_project_directory()
     multi_projects = config.get_migman_multi_projects()
     projects = get_migman_project_list(config)
+    if not projects:
+        raise ValueError("No migman projects defined.")
 
     database = MigManDatabaseLoad()
     for project in projects:
