@@ -15,9 +15,9 @@ import logging
 def LoadReport(
     config: Config,
     projectname: str,
-    report_guid: str = None,
-    report_name: str = None,
-    data_types = None,
+    report_guid: str | None = None,
+    report_name: str | None = None,
+    data_types: list[str] | None = None,
 ) -> pd.DataFrame:
     """
     Loads a report from a specified project and returns the data as a Pandas DataFrame.
@@ -113,12 +113,7 @@ def _download_and_process_csv(csv_url, data_types=None) -> pd.DataFrame:
                 keep_default_na=False,
             )
         else:
-            result = pd.read_csv(
-                tmp_path,
-                sep=",",
-                quotechar='"',
-                escapechar="\\"
-            )
+            result = pd.read_csv(tmp_path, sep=",", quotechar='"', escapechar="\\")
 
         # Drop optional metadata column
         if "_RECORD_COUNT" in result.columns:
@@ -132,4 +127,4 @@ def _download_and_process_csv(csv_url, data_types=None) -> pd.DataFrame:
         if os.path.exists(tmp_path):
             os.remove(tmp_path)
 
-    return result
\ No newline at end of file
+    return result
