@@ -56,9 +56,9 @@ def getProjectProperty(
 def setProjectMetaData(
     config: Config,
     projectname: str,
-    processid_column: str = None,
-    processdate_column: str = None,
-    corpcurr_value: str = None,
+    processid_column: str | None = None,
+    processdate_column: str | None = None,
+    corpcurr_value: str | None = None,
 ) -> None:
     """
     Updates metadata for a specific project, including process ID, process date, and corporate currency value.
