@@ -95,21 +95,39 @@ class Config:
             path = Path(read_files[0])
             logging.info(f"Successfully read config file: {path.absolute()}")
 
-        self.tenant = tenant or self.config.get("nemo_library", "tenant", fallback=None)
+        tenant = tenant or self.config.get("nemo_library", "tenant", fallback=None)
+        if not tenant:
+            raise ValueError("Tenant must be specified either as an argument or in the config file.")
+        self.tenant = tenant
         logging.info(f"Using tenant: {self.tenant}")
-        self.userid = userid or self.config.get("nemo_library", "userid", fallback=None)
+        
+        userid = userid or self.config.get("nemo_library", "userid", fallback=None)
+        if not userid:
+            raise ValueError("User ID must be specified either as an argument or in the config file.")
+        self.userid = userid
         logging.info(f"Using user ID: {self.userid}")
-        self.password = password or self.config.get(
+
+
+        password = password or self.config.get(
             "nemo_library", "password", fallback=None
         )
-
-        if self.password is None:
+        if not password:
             pm = PasswordManager(service_name="nemo_library", username=self.userid)
-            self.password = pm.get_password()
+            password = pm.get_password()
+            
+        if not password:
+            raise ValueError("Password must be specified either as an argument, in the config file, or in the password manager.")
+        self.password = password
+        logging.info("Using provided password.")
 
-        self.environment = environment or self.config.get(
+        environment = environment or self.config.get(
             "nemo_library", "environment", fallback=None
         )
+        if not environment:
+            raise ValueError("Environment must be specified either as an argument or in the config file.")
+        if environment not in NEMO_URLS:
+            raise ValueError(f"Unknown environment '{environment}' provided. Environment must be one of {list(NEMO_URLS.keys())}")
+        self.environment = environment
         logging.info(f"Using environment: {self.environment}")
 
         self.migman_local_project_directory = (
@@ -264,30 +282,30 @@ class Config:
         """
         return self.environment
 
-    def get_hubspot_api_token(self) -> str:
+    def get_hubspot_api_token(self) -> str | None:
         """
         Retrieves the HubSpot API token.
 
         Returns:
-            str: The HubSpot API token.
+            str | None: The HubSpot API token.
         """
         return self.hubspot_api_token
 
-    def get_migman_local_project_directory(self) -> str:
+    def get_migman_local_project_directory(self) -> str | None:
         """
         Retrieves the local project directory for MigMan.
 
         Returns:
-            str: The local project directory for MigMan.
+            str | None: The local project directory for MigMan.
         """
         return self.migman_local_project_directory
 
-    def get_migman_proALPHA_project_status_file(self) -> str:
+    def get_migman_proALPHA_project_status_file(self) -> str | None:
         """
         Retrieves the status file for proALPHA projects.
 
         Returns:
-            str: The status file for proALPHA projects.
+            str | None: The status file for proALPHA projects or None if not set.
         """
         return self.migman_proALPHA_project_status_file
 
@@ -412,12 +430,12 @@ class Config:
         except KeyError:
             raise Exception(f"unknown environment '{env}' provided. Environment must be one of {list(COGNITO_APPCLIENT_IDS.keys())}")
 
-    def connection_get_tokens(self) -> tuple[str, str, str]:
+    def connection_get_tokens(self) -> tuple[str | None, str | None, str | None]:
         """
         Retrieves the tokens for the connection, caching them after first request.
 
         Returns:
-            tuple[str, str, str]: The ID token, access token, and refresh token.
+            tuple[str | None, str | None, str | None]: The ID token, access token, and refresh token.
         """
         # Return cached tokens if they exist
         if self._id_token and self._access_token:
