@@ -301,8 +301,13 @@ def getMappingRelations(config: Config) -> pd.DataFrame:
     """
     # get configuration
     mapping_fields = config.get_migman_mapping_fields()
+    if not mapping_fields:
+        logging.info(f"no mapping fields defined")
+        return pd.DataFrame()
     additional_fields = config.get_migman_additional_fields()
     migman_projects = get_migman_project_list(config)
+    if not migman_projects:
+        raise ValueError("No migman projects defined.")
 
     # get data projects
     projects_display_name_migman = [
@@ -343,7 +348,7 @@ def getMappingRelations(config: Config) -> pd.DataFrame:
                         break
 
             # If the mapping field or one of its synonyms is found
-            if matching_field:
+            if matching_field and additional_fields:
 
                 # Check if all additional fields are also present
                 additional_fields_present = all(
@@ -419,7 +424,9 @@ def sqlQueryInMappingTable(
     internal_names = mappingrelationsdf["matching_field_internal_name"].to_list()
     additional_fields = mappingrelationsdf["additional_fields"].to_list()
     additional_fields_defined = config.get_migman_additional_fields()
-    additional_field_global_definition = additional_fields_defined.get(field, [])
+    additional_field_global_definition = (
+        additional_fields_defined.get(field, []) if additional_fields_defined else []
+    )
 
     # setup CTEs to load data from source projects
     ctes = []
@@ -496,7 +503,7 @@ ON
 def is_migman_project_existing(
     database: list[MigMan],
     project: str,
-) -> True:
+) -> bool:
     return len([x.nemo_import_name for x in database if x.project == project]) > 0
 
 
@@ -533,7 +540,7 @@ def get_migman_mandatory_fields(
 
 def get_mig_man_field(
     database: list[MigMan], project: str, postfix: str, index: int
-) -> MigMan:
+) -> MigMan | None:
     columns = [
         x
         for x in database
